import 'dart:collection';

import 'package:flutter/material.dart';
import 'package:flutter_inappwebview/flutter_inappwebview.dart';

import 'package:airbridge_flutter_sdk_example/basic/import.dart';

class InAppWebViewHostPage extends StatefulWidget {
  @override
  _InAppWebViewHostPageState createState() =>
      new _InAppWebViewHostPageState();
}
class _InAppWebViewHostPageState extends State<InAppWebViewHostPage> {

  var webInterface;
  final GlobalKey webViewKey = GlobalKey();
  InAppWebViewController? webViewController;

  @override
  Widget build(BuildContext context) {
    Log.info('InAppWebViewHostPage build');

    webInterface = Airbridge.createWebInterface(
      webToken: '8ec37a00b37a4576a7f8bdf8d5164dd5',
      postCommandFunction: (arg) {
        return """window.flutter_inappwebview.callHandler('postMessage', $arg);"""; 
    });

    InAppWebViewGroupOptions options = InAppWebViewGroupOptions(
      crossPlatform: InAppWebViewOptions(
        useShouldOverrideUrlLoading: true
      ));
    Uri uri = Uri.parse("https://dev.blog.airbridge.io/sdk-qa/");

    return SafeArea(
        child: Column(
            children: [
                Expanded(
                  child: Stack(
                    children: [
                      InAppWebView(
                        initialOptions: options,
                        key: webViewKey,
                        initialUrlRequest: URLRequest(url: uri),
                        onWebViewCreated: (controller) async {
                          webViewController = controller;
                          controller.addJavaScriptHandler(handlerName: 'postMessage', callback: (args) {
                            webInterface.handle(args[0]);
                            return args;
                          });
                        },
                        initialUserScripts: UnmodifiableListView<UserScript>([
                          UserScript(
                            source: webInterface.script, 
                            injectionTime: UserScriptInjectionTime.AT_DOCUMENT_START)
                        ]),
                        onConsoleMessage: (controller, consoleMessage) {
                          Log.info(consoleMessage.toString());
                        },
                        shouldOverrideUrlLoading: (controller, navigationAction) async {
                          var uri = navigationAction.request.url!;
                          Log.info("shouldOverrideUrlLoading : " + uri.toString());
                          if (![
                            "http",
                            "https",
                            "file",
                            "chrome",
                            "data",
                            "javascript",
                            "about"
                          ].contains(uri.scheme)) {
                              Log.info("shouldOverrideUrlLoading NavigationActionPolicy.CANCEL");
                              return NavigationActionPolicy.CANCEL;
                          }

                          Log.info("shouldOverrideUrlLoading NavigationActionPolicy.ALLOW");
                          return NavigationActionPolicy.ALLOW;
                        }
                      )
                    ]
                  )
                ),
                ButtonBar(
                  alignment: MainAxisAlignment.center,
                  children: <Widget>[
                    ElevatedButton(
                      child: Icon(Icons.arrow_back),
                      onPressed: () {
                        webViewController?.goBack();
                      },
                    ),
                    ElevatedButton(
                      child: Icon(Icons.arrow_forward),
                      onPressed: () {
                        webViewController?.goForward();
                      },
                    ),
                    ElevatedButton(
                      child: Icon(Icons.refresh),
                      onPressed: () {
                        webViewController?.reload();
                      },
                    ),
                  ],
                )
            ],
        )
    );
  }
}